#!/bin/bash
echo " Timer Install Script...."
while true 
do 
	if [ -f "/home/root/b110_update.tar" ]; then
		sleep 5 
		sync
		cd /home/root
		chmod +x install.sh
		./install.sh
		exit
	else
		sleep 5 
	fi
done
